import time

from test_pioneer.logging.loggin_instance import step_log_check, test_pioneer_logger


def blocked_wait(step: dict, enable_logging: bool, ) -> bool:
    if not isinstance(step.get("wait"), int):
        step_log_check(
            enable_logging=enable_logging, logger=test_pioneer_logger, level="info",
            message=f"The 'wait' parameter is not an int type: {step.get('wait')}")
        return False
    step_log_check(
        enable_logging=enable_logging, logger=test_pioneer_logger, level="info",
        message=f"Wait seconds: {step.get('wait')}")
    time.sleep((step.get("wait")))
    return True



from je_auto_control import RecordingThread

from test_pioneer.utils.exception.exceptions import ExecutorException


def set_recoder(yaml_data: dict) -> tuple[bool, RecordingThread] or None:
    # Pre-check recoding or no
    if "recording_path" in yaml_data.keys():
        if isinstance(yaml_data.get("recording_path"), str) is False:
            raise ExecutorException(f"recording_path not a str: {yaml_data.get('recording_path')}")
        import sys
        if 'threading' in sys.modules:
            del sys.modules['threading']
        from gevent.monkey import patch_thread
        patch_thread()
        recording = True
        recoder = RecordingThread()
        recoder.video_name = yaml_data.get("recording_path")
        recoder.daemon = True
        recoder.start()
        return recording, recoder
    else:
        return False, None
